# Calibration

::: survey_kit.calibration.moment.Moment
    options:
        show_root_heading: true
        show_root_full_path: false
        heading_level: 2

::: survey_kit.calibration.calibration.Calibration
    options:
        show_root_heading: true
        show_root_full_path: false
        heading_level: 2
        members:
            - run
            - print_diagnostics
            - get_final_weights

::: survey_kit.calibration.trim.Trim
    options:
        show_root_heading: true
        show_root_full_path: false
        heading_level: 2
